@@ -24,10 +24,10 @@ def SchedulerMethod(*methodArgs, requestClass=None, **methodKwargs) :
         methodClassName = ReflectionHelper.getMethodClassName(resourceInstanceMethod)
         methodName = ReflectionHelper.getName(resourceInstanceMethod)
         methodKwargs['id'] = methodKwargs.get('id', f'{methodClassName}{c.DOT}{methodName}')
-        # instancesUpTo = methodKwargs.pop('instancesUpTo', 1)
-        # weekDays = methodKwargs.pop('weekDays', None)
-        # methodKwargs['max_instances'] = instancesUpTo
-        # methodKwargs['day_of_week'] = weekDays
+        instancesUpTo = methodKwargs.pop('instancesUpTo', 1)
+        weekDays = methodKwargs.pop('weekDays', None)
+        methodKwargs['max_instances'] = instancesUpTo
+        methodKwargs['day_of_week'] = weekDays
         shedulerArgs = [*methodArgs]
         shedulerArgs = {**methodKwargs}
         apiInstance = resourceInstanceMethod.__self__.globals.api
